==> e107-0.7.20.tbz: www/e107/e107_languages/English/lan_signup.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_languages/English/lan_signup.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/
define("PAGE_NAME", "Register");
define("LAN_7", "Display Name: ");
define("LAN_8", "the name that will be displayed on site");
define("LAN_9", "Username: ");
define("LAN_10", "the name that you use to login");
define("LAN_17", "Password: ");
define("LAN_103", "That username cannot be accepted as valid, please choose a different user name");
define("LAN_104", "That username already exists in the database, please choose a different username");
define("LAN_105", "The two passwords do not match");
define("LAN_106", "That doesn't appear to be a valid email address");
define("LAN_107", "Thank you! You are now a registered member of");
define("LAN_108", "Registration complete");
define("LAN_109", "This site complies with The Children's Online Privacy Protection Act of 1998 (COPPA) and as such cannot accept registrations from users under the age of 13 without a written permission document from their parent or guardian. For more information you can read the legislation");
define("LAN_110", "Registration");
define("LAN_111", "Re-type Password: ");
define("LAN_112", "Email Address: ");
define("LAN_113", "Hide email address?: ");
define("LAN_114", "This will prevent your email address from being displayed on site");
define("LAN_123", "Register");
define("LAN_185", "You left required field(s) blank");
define("LAN_201", "Yes");
define("LAN_200", "No");
define("LAN_202", "You already have an account. If you have forgotten your password, please click the 'forgot password' link.");
define("LAN_309", "Please enter your details below.");
define("LAN_399", "Continue");
define("LAN_400", "Usernames and passwords are <b>case-sensitive</b>.");
define("LAN_401", "Your account has now been activated, please");
define("LAN_402", "Registration activated");
define("LAN_403", "Welcome to");
define("LAN_404", "Registration details for");
define("LAN_405", "This stage of registration is complete. You will receive a confirmation email containing your login details. Please follow the link in the email to complete the signup process and activate your account.");
define("LAN_406", "Thank you!");
define("LAN_407", "Please keep this email for your own information. Your password has been encrypted and cannot be retrieved if you misplace or forget it. You can however request a new password if this happens.\n\nThanks for your registration.\n\nFrom");
define("LAN_408", "A user with that email address already exists. Please use the 'forgot password' screen to retrieve your password.");
define("LAN_SIGNUP_1", "Min.");
define("LAN_SIGNUP_2", "chars.");
define("LAN_SIGNUP_3", "Code verification failed.");
define("LAN_SIGNUP_4", "Your password must be at least ");
define("LAN_SIGNUP_5", " characters long.");
define("LAN_SIGNUP_6", "Your ");
define("LAN_SIGNUP_7", " is required");
define("LAN_SIGNUP_8", "Thank you!");
define("LAN_SIGNUP_9", "Unable to proceed.");
define("LAN_SIGNUP_10", "Yes");
define("LAN_SIGNUP_11", ".");

define("LAN_409", "Invalid characters in username");
define("LAN_410", "Enter code visible in the image");
define("LAN_411", "That display name already exists in the database, please choose a different display name");


define("LAN_SIGNUP_12", "please keep your username and password written down in a safe place as if lost they cannot be retrieved.");
define("LAN_SIGNUP_13", "You can now log in from the Login box, or from <a href='".e_BASE."login.php'>here</a>.");
define("LAN_SIGNUP_14", "here");
define("LAN_SIGNUP_15", "Please contact the main site admin");
define("LAN_SIGNUP_16", "if you require assistance.");
define("LAN_SIGNUP_17", "Please certify you are 13 or over the age of 13.");
define("LAN_SIGNUP_18", "Your registration has been received and created with the following login information:");
//define("LAN_SIGNUP_19", "Username:"); // now LAN_LOGINNAME
//define("LAN_SIGNUP_20", "Password:"); // now LAN_PASSWORD
define("LAN_SIGNUP_21", "Your account is currently marked as being inactive. To activate your account please go to the following link:");
define("LAN_SIGNUP_22", "click here");
define("LAN_SIGNUP_23", "to login.");
define("LAN_SIGNUP_24", "Thank you for registering at");
define("LAN_SIGNUP_25", "Upload your avatar");
define("LAN_SIGNUP_26", "Upload your photograph");
define("LAN_SIGNUP_27", "Show");
define("LAN_SIGNUP_28", "choice of Content/Mail-lists");
define("LAN_SIGNUP_29", "A verification email will be sent to the email address you enter here so it must be valid.");
define("LAN_SIGNUP_30", "If you do not wish to display your email address on this site, please select 'Yes' for the 'Hide email address?' option.");

define("LAN_SIGNUP_31", "URL to your XUP file");
define("LAN_SIGNUP_32", "What's an XUP file?");
define("LAN_SIGNUP_33", "Type path or choose avatar");
define("LAN_SIGNUP_34", "Please note: Any image uploaded to this server that is deemed inappropriate by the administrators will be deleted immediately.");
define("LAN_SIGNUP_35", "Click here to register using an XUP file");
define("LAN_SIGNUP_36", "An error has occurred creating your user information, please contact the site admin");

define("LAN_LOGINNAME", "Username");
define("LAN_PASSWORD", "Password");
define("LAN_USERNAME", "Display Name");
define("LAN_EMAIL_01", "Dear");
define("LAN_EMAIL_04", "Please keep this email for your own information.");
define("LAN_EMAIL_05", "Your password has been encrypted and cannot be retrieved if you misplace or forget it. You can however request a new password if this happens.");
define("LAN_EMAIL_06", "Thanks for your registration.");

define("LAN_SIGNUP_37", "This stage of registration is complete. The site admin will need to approve your membership.  Once this has been done you will receive a confirmation email alerting you that your membership has been approved.");
define("LAN_SIGNUP_38", "You entered two different email addresses. Please enter a valid email address in the two fields provided");
define("LAN_SIGNUP_39", "Re-type Email Address:");

// 0.7.6
define("LAN_SIGNUP_40", "Activation not necessary");
define("LAN_SIGNUP_41", "Your account is already activated.");
define("LAN_SIGNUP_42", "There was a problem, the registration mail was not sent, please contact the website administrator.");
define("LAN_SIGNUP_43", "Email Sent");
define("LAN_SIGNUP_44", "Activation email sent to:");
define("LAN_SIGNUP_45", "Please check your inbox.");
define("LAN_SIGNUP_47", "Resend Activation Email");
define("LAN_SIGNUP_48", "Username or Email");
define("LAN_SIGNUP_49", "If you registered with the wrong email address, type a new one and your password here:");
define("LAN_SIGNUP_50", "New Email");
define("LAN_SIGNUP_51", "Old Password");
define("LAN_SIGNUP_52", "Incorrect Password");
define("LAN_SIGNUP_53", "field failed validation test");
define("LAN_SIGNUP_54", "Click here to fill in your details to register");
define("LAN_SIGNUP_55", "That display name is too long. Please choose another");
define("LAN_SIGNUP_56", "That display name is too short. Please choose another");
define("LAN_SIGNUP_57", "That login name is too long. Please choose another");
define("LAN_SIGNUP_58", "Signup Preview");
define("LAN_SIGNUP_59","**** If the link doesn't work, please check that part of it has not overflowed onto the next line. ****");
define('LAN_SIGNUP_60', 'Error accessing external avatar');

// 0.7.16

define("LAN_SIGNUP_72", "Thanks for signing up on [sitename]! We just sent you a confirmation email to [email]. Please click on the confirmation link in the email to complete your sign up and activate your account.");  	// LAN_405

define("LAN_SIGNUP_98", "Confirm Your Email Address");
define("LAN_SIGNUP_99", "Problem Encountered");
define("LAN_SIGNUP_100", "Admin Approval Pending");




?>

==> e107-1.0.3.tbz: www/e107/e107_languages/English/lan_signup.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_languages/English/lan_signup.php $
|     $Revision: 12130 $
|     $Id: lan_signup.php 12130 2011-04-12 21:09:45Z e107steved $
|     $Author: e107steved $
+----------------------------------------------------------------------------+
*/
define("PAGE_NAME", "Register");
define("LAN_7", "Display Name: ");
define("LAN_8", "the name that will be displayed on site");
define("LAN_9", "Username: ");
define("LAN_10", "the name that you use to login");
define("LAN_17", "Password: ");
define("LAN_103", "That username cannot be accepted as valid, please choose a different user name");
define("LAN_104", "That username already exists in the database, please choose a different username");
define("LAN_105", "The two passwords do not match");
define("LAN_106", "That doesn't appear to be a valid email address");
define("LAN_107", "Thank you! You are now a registered member of");
define("LAN_108", "Registration complete");
define("LAN_109", "This site complies with The Children's Online Privacy Protection Act of 1998 (COPPA) and as such cannot accept registrations from users under the age of 13 without a written permission document from their parent or guardian. For more information you can read the legislation");
define("LAN_110", "Registration");
define("LAN_111", "Re-type Password: ");
define("LAN_112", "Email Address: ");
define("LAN_113", "Hide email address?: ");
define("LAN_114", "This will prevent your email address from being displayed on site");
define("LAN_123", "Register");
define("LAN_185", "You left required field(s) blank");
define("LAN_201", "Yes");
define("LAN_200", "No");
define("LAN_202", "You already have an account. If you have forgotten your password, please click the 'forgot password' link.");
define("LAN_309", "Please enter your details below.");
define("LAN_399", "Continue");
define("LAN_400", "Usernames and passwords are <b>case-sensitive</b>.");
define("LAN_401", "Your account has now been activated, please");
define("LAN_402", "Registration activated");
define("LAN_403", "Welcome to");
define("LAN_404", "Registration details for");
define("LAN_405", "This stage of registration is complete. You will receive a confirmation email containing your login details. Please follow the link in the email to complete the signup process and activate your account.");
define("LAN_406", "Thank you!");
define("LAN_407", "Please keep this email for your own information. Your password has been encrypted and cannot be retrieved if you misplace or forget it. You can however request a new password if this happens.\n\nThanks for your registration.\n\nFrom");
define("LAN_408", "A user with that email address already exists. Please use the 'forgot password' screen to retrieve your password.");
define("LAN_SIGNUP_1", "Min.");
define("LAN_SIGNUP_2", "chars.");
define("LAN_SIGNUP_3", "Code verification failed.");
define("LAN_SIGNUP_4", "Your password must be at least ");
define("LAN_SIGNUP_5", " characters long.");
define("LAN_SIGNUP_6", "Your ");
define("LAN_SIGNUP_7", " is required");
define("LAN_SIGNUP_8", "Thank you!");
define("LAN_SIGNUP_9", "Unable to proceed.");
define("LAN_SIGNUP_10", "Yes");
define("LAN_SIGNUP_11", ".");

define("LAN_409", "Invalid characters in username");
define("LAN_410", "Enter code visible in the image");
define("LAN_411", "That display name already exists in the database, please choose a different display name");


define("LAN_SIGNUP_12", "please keep your username and password written down in a safe place as if lost they cannot be retrieved.");
define("LAN_SIGNUP_13", "You can now log in from the Login box, or from <a href='".e_BASE."login.php'>here</a>.");
define("LAN_SIGNUP_14", "here");
define("LAN_SIGNUP_15", "Please contact the main site admin");
define("LAN_SIGNUP_16", "if you require assistance.");
define("LAN_SIGNUP_17", "Please certify you are 13 or over the age of 13.");
define("LAN_SIGNUP_18", "Your registration has been received and created with the following login information:");
//define("LAN_SIGNUP_19", "Username:"); // now LAN_LOGINNAME
//define("LAN_SIGNUP_20", "Password:"); // now LAN_PASSWORD
define("LAN_SIGNUP_21", "Your account is currently marked as being inactive. To activate your account please go to the following link:");
define("LAN_SIGNUP_22", "click here");
define("LAN_SIGNUP_23", "to login.");
define("LAN_SIGNUP_24", "Thank you for registering at");
define("LAN_SIGNUP_25", "Upload your avatar");
define("LAN_SIGNUP_26", "Upload your photograph");
define("LAN_SIGNUP_27", "Show");
define("LAN_SIGNUP_28", "choice of Content/Mail-lists");
define("LAN_SIGNUP_29", "A verification email will be sent to the email address you enter here so it must be valid.");
define("LAN_SIGNUP_30", "If you do not wish to display your email address on this site, please select 'Yes' for the 'Hide email address?' option.");

define("LAN_SIGNUP_31", "URL to your XUP file");
define("LAN_SIGNUP_32", "What's an XUP file?");
define("LAN_SIGNUP_33", "Type path or choose avatar");
define("LAN_SIGNUP_34", "Please note: Any image uploaded to this server that is deemed inappropriate by the administrators will be deleted immediately.");
define("LAN_SIGNUP_35", "Click here to register using an XUP file");
define("LAN_SIGNUP_36", "An error has occurred creating your user information, please contact the site admin");

define("LAN_LOGINNAME", "Username");
define("LAN_PASSWORD", "Password");
define("LAN_USERNAME", "Display Name");
define("LAN_EMAIL_01", "Dear");
define("LAN_EMAIL_04", "Please keep this email for your own information.");
define("LAN_EMAIL_05", "Your password has been encrypted and cannot be retrieved if you misplace or forget it. You can however request a new password if this happens.");
define("LAN_EMAIL_06", "Thanks for your registration.");

define("LAN_SIGNUP_37", "This stage of registration is complete. The site admin will need to approve your membership.  Once this has been done you will receive a confirmation email alerting you that your membership has been approved.");
define("LAN_SIGNUP_38", "You entered two different email addresses. Please enter a valid email address in the two fields provided");
define("LAN_SIGNUP_39", "Re-type Email Address:");

// 0.7.6
define("LAN_SIGNUP_40", "Activation not necessary");
define("LAN_SIGNUP_41", "Your account is already activated.");
define("LAN_SIGNUP_42", "There was a problem, the registration mail was not sent, please contact the website administrator.");
define("LAN_SIGNUP_43", "Email Sent");
define("LAN_SIGNUP_44", "Activation email sent to:");
define("LAN_SIGNUP_45", "Please check your inbox.");
define("LAN_SIGNUP_47", "Resend Activation Email");
define("LAN_SIGNUP_48", "Username or Email");
define("LAN_SIGNUP_49", "If you registered with the wrong email address, type a new one and your password here:");
define("LAN_SIGNUP_50", "New Email");
define("LAN_SIGNUP_51", "Old Password");
define("LAN_SIGNUP_52", "Incorrect Password");
define("LAN_SIGNUP_53", "field failed validation test");
define("LAN_SIGNUP_54", "Click here to fill in your details to register");
define("LAN_SIGNUP_55", "That display name is too long. Please choose another");
define("LAN_SIGNUP_56", "That display name is too short. Please choose another");
define("LAN_SIGNUP_57", "That login name is too long. Please choose another");
define("LAN_SIGNUP_58", "Signup Preview");
define("LAN_SIGNUP_59","**** If the link doesn't work, please check that part of it has not overflowed onto the next line. ****");
define('LAN_SIGNUP_60', 'Error accessing external avatar');

// 0.7.16

define("LAN_SIGNUP_72", "Thanks for signing up on [sitename]! We just sent you a confirmation email to [email]. Please click on the confirmation link in the email to complete your sign up and activate your account.");  	// LAN_405

define("LAN_SIGNUP_98", "Confirm Your Email Address");
define("LAN_SIGNUP_99", "Problem Encountered");
define("LAN_SIGNUP_100", "Admin Approval Pending");


define('LAN_SIGNUP_102', 'Signup refused');
define('LAN_SIGNUP_103', 'Too many users already using IP address: ');
define('LAN_SIGNUP_104', 'Invalid avatar name');
define('LAN_SIGNUP_105', 'Unable to action your request - please contact the site administrator');		// Two people with same password.
define('LAN_SIGNUP_106', 'Unable to action your request - do you already have an account here?');		// Trying to set email same as existing

?>
